"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogWorker = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const errors_1 = require("@jfrog-pipelines/errors");
const ArchiveCommand_1 = require("./archive/ArchiveCommand");
const WebConsoleArchiveHandler_1 = require("./archive/WebConsoleArchiveHandler");
class LogWorker {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('LogWorker');
        this.eventLogger = logger_1.LoggerFactory.getEventLogger();
    }
    async process(message) {
        try {
            const archivalPayload = message;
            this.validate(archivalPayload);
            const type = archivalPayload.payload.objectType;
            const id = archivalPayload.payload.objectId;
            const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, id);
            const webConsoleArchiveHandler = new WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler(this.eventLogger);
            await webConsoleArchiveHandler.handle(archiveCommand);
        }
        catch (error) {
            this.logger.error('Message was not processed successfully', (0, node_util_1.inspect)(error));
        }
    }
    validate(message) {
        this.validatePayload(message);
        const payload = message.payload;
        if (payload.objectType !== ArchiveCommand_1.STEP) {
            throw new errors_1.InvalidMessageError(`Invalid ObjectType found in message ${payload.objectType}`);
        }
        if (!Number.isInteger(payload.objectId)) {
            throw new errors_1.InvalidMessageError(`Invalid ObjectType found in message ${payload.objectType}`);
        }
        if (Number.isNaN(Date.parse(payload.queuedAt))) {
            throw new errors_1.InvalidMessageError(`Invalid ObjectType found in message ${payload.objectType}`);
        }
    }
    validatePayload(message) {
        if (!(message.payload?.objectId && message.payload.objectType && message.payload.queuedAt)) {
            throw new errors_1.InvalidMessageError(`Invalid ObjectType found in message ${message.payload}`);
        }
    }
}
exports.LogWorker = LogWorker;
//# sourceMappingURL=LogWorker.js.map