"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const LogWorker_1 = require("../LogWorker");
const WebConsoleArchiveHandler_1 = require("../archive/WebConsoleArchiveHandler");
const ArchiveCommand_1 = require("../archive/ArchiveCommand");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'apitoken' } }
    };
});
jest.mock('@jfrog-pipelines/logger');
const logger = {
    trace: jest.fn(),
    debug: jest.fn(),
    error: jest.fn(),
    warn: jest.fn(),
    info: jest.fn()
};
logger_1.LoggerFactory.getLogger.mockImplementation(() => logger);
describe('Log Worker', () => {
    const logWorker = new LogWorker_1.LogWorker();
    it('should process message as it is valid', async () => {
        const stepId = 1;
        const type = 'step';
        const message = {
            payload: {
                objectType: type,
                objectId: stepId,
                queuedAt: new Date()
            }
        };
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const handleSpy = jest.spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle').mockResolvedValue();
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledWith(archiveCommand);
        expect(handleSpy).toHaveBeenCalledTimes(1);
    });
    it('should not process message as handle rejects', async () => {
        const stepId = 1;
        const type = 'step';
        const message = {
            payload: {
                objectType: type,
                objectId: stepId,
                queuedAt: new Date()
            }
        };
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const handleSpy = jest
            .spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle')
            .mockRejectedValue(new Error('invalid stepId'));
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledWith(archiveCommand);
        expect(handleSpy).toHaveBeenCalledTimes(1);
        expect(logger.error).toHaveBeenCalledTimes(1);
    });
    it('should not process message as invalid type present', async () => {
        const stepId = 1;
        const type = 'xyz';
        const message = {
            payload: {
                objectType: type,
                objectId: stepId,
                queuedAt: new Date()
            }
        };
        const handleSpy = jest.spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle').mockResolvedValue();
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledTimes(0);
        expect(logger.error).toHaveBeenCalledTimes(1);
    });
    it('should not process message as objectId is not present', async () => {
        const type = 'xyz';
        const message = {
            payload: {
                objectType: type,
                queuedAt: new Date()
            }
        };
        const handleSpy = jest.spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle').mockResolvedValue();
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledTimes(0);
        expect(logger.error).toHaveBeenCalledTimes(1);
    });
    it('should not process message as invalid objectId present', async () => {
        const stepId = 'check';
        const type = 'step';
        const message = {
            inPayload: {
                objectType: type,
                objectId: stepId,
                queuedAt: new Date()
            }
        };
        const handleSpy = jest.spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle').mockResolvedValue();
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledTimes(0);
        expect(logger.error).toHaveBeenCalledTimes(1);
    });
    it('should not process message as invalid date present', async () => {
        const stepId = 1;
        const type = 'step';
        const message = {
            inPayload: {
                objectType: type,
                objectId: stepId,
                queuedAt: 'test'
            }
        };
        const handleSpy = jest.spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'handle').mockResolvedValue();
        await logWorker.process(message);
        expect(handleSpy).toHaveBeenCalledTimes(0);
        expect(logger.error).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=LogWorker.test.js.map