"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebConsoleArchiveCommandHandler = void 0;
const logger_1 = require("@jfrog-pipelines/logger");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const StepServiceRepository_1 = require("../acl/stepService/StepServiceRepository");
const ArchiveCommand_1 = require("./ArchiveCommand");
const StepConsoleRepository_1 = require("./StepConsoleRepository");
const StepletConsoleRepository_1 = require("./StepletConsoleRepository");
class WebConsoleArchiveCommandHandler {
    constructor(eventLogger) {
        this.stepServiceRepository = new StepServiceRepository_1.StepServiceRepository();
        this.stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository();
        this.stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository();
        this.eventLogger = eventLogger;
    }
    async handle(command) {
        const startTime = Date.now();
        const eventData = {
            domain: 'log-service',
            eventType: 'onArchive',
            stepId: command.getId(),
            status: 'success',
            durationMillis: 0
        };
        try {
            const stepMetricData = await this.deleteStepArchivedConsole(command.getId());
            const stepletMetricData = await this.deleteStepletArchivedConsole(command.getId());
            eventData.stepConsoleCount = stepMetricData.count;
            eventData.stepletConsoleCount = stepletMetricData.count;
            eventData.deletedStepConsole = stepMetricData.deleted;
            eventData.deletedStepletConsole = stepletMetricData.deleted;
        }
        catch {
            eventData.status = 'failed';
        }
        finally {
            const stopTime = Date.now();
            const timeDiff = new Date(stopTime - startTime);
            eventData.durationMillis = timeDiff.valueOf();
            this.logEvent(eventData);
        }
    }
    async deleteStepArchivedConsole(stepId) {
        const archived = await this.isStepArchived(stepId);
        if (archived) {
            return this.deleteStepConsoleByStepId(stepId);
        }
        return {
            count: 0,
            deleted: 0
        };
    }
    async deleteStepletArchivedConsole(stepId) {
        const steplets = await this.getStepletsByStepId(stepId);
        const stepletIdsToDelete = steplets.filter((steplet) => steplet.isConsoleArchived).map((steplet) => steplet.id);
        const metricCountArray = await Promise.all(stepletIdsToDelete.map((id) => this.deleteStepletConsoleByStepletId(id)));
        const result = {
            count: 0,
            deleted: 0
        };
        for (const metricCount of metricCountArray) {
            result.count = result.count + metricCount.count;
            result.deleted = result.deleted + metricCount.deleted;
        }
        return result;
    }
    async isStepArchived(stepId) {
        const step = await this.stepServiceRepository.getStepById(stepId);
        return step.isConsoleArchived;
    }
    async deleteStepConsoleByStepId(stepId) {
        const deleteQuery = new data_access_layer_1.SequelizeQueryBuilder({}).where('stepId', stepId).build();
        const count = (await this.stepConsoleRepository.count(deleteQuery));
        const deleted = await this.stepConsoleRepository.delete(deleteQuery);
        const metricCount = {
            count,
            deleted
        };
        return metricCount;
    }
    async getStepletsByStepId(stepId) {
        const steplet = await this.stepServiceRepository.getStepletsByStepId(stepId);
        return steplet;
    }
    async deleteStepletConsoleByStepletId(stepletId) {
        const deleteQuery = new data_access_layer_1.SequelizeQueryBuilder({}).where('stepletId', stepletId).build();
        const count = (await this.stepletConsoleRepository.count(deleteQuery));
        const deleted = await this.stepletConsoleRepository.delete(deleteQuery);
        const metricCount = {
            count,
            deleted
        };
        return metricCount;
    }
    logEvent(eventData) {
        this.eventLogger.info(JSON.stringify(eventData));
    }
}
__decorate([
    (0, logger_1.Log)(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [ArchiveCommand_1.ArchiveCommand]),
    __metadata("design:returntype", Promise)
], WebConsoleArchiveCommandHandler.prototype, "handle", null);
exports.WebConsoleArchiveCommandHandler = WebConsoleArchiveCommandHandler;
//# sourceMappingURL=WebConsoleArchiveHandler.js.map